@@ -23,12 +23,13 @@ from __future__ import absolute_import
 
 import json
 from .watson_service import WatsonService
+from .utils import deprecated
 
 ##############################################################################
 # Service
 ##############################################################################
 
-
+@deprecated("watson-developer-cloud moved to ibm-watson. To get updates, use the new package.")
 class AssistantV2(WatsonService):
     """The Assistant V2 service."""
 
