@@ -26,12 +26,13 @@ from __future__ import absolute_import
 import json
 from os.path import basename
 from .watson_service import WatsonService
+from .utils import deprecated
 
 ##############################################################################
 # Service
 ##############################################################################
 
-
+@deprecated("watson-developer-cloud moved to ibm-watson. To get updates, use the new package.")
 class LanguageTranslatorV3(WatsonService):
     """The Language Translator V3 service."""
 
