@@ -26,12 +26,13 @@ import json
 from .watson_service import datetime_to_string, string_to_datetime
 from os.path import basename
 from .watson_service import WatsonService
+from .utils import deprecated
 
 ##############################################################################
 # Service
 ##############################################################################
 
-
+@deprecated("watson-developer-cloud moved to ibm-watson. To get updates, use the new package.")
 class NaturalLanguageClassifierV1(WatsonService):
     """The Natural Language Classifier V1 service."""
 
