@@ -26,12 +26,13 @@ from .watson_service import datetime_to_string, string_to_datetime
 from os.path import basename
 import re
 from .watson_service import WatsonService
+from .utils import deprecated
 
 ##############################################################################
 # Service
 ##############################################################################
 
-
+@deprecated("watson-developer-cloud moved to ibm-watson. To get updates, use the new package.")
 class VisualRecognitionV3(WatsonService):
     """The Visual Recognition V3 service."""
 
