@@ -326,7 +326,7 @@ class WatsonService(object):
                 for line in fp:
                     key_val = line.strip().split(separator)
                     if len(key_val) == 2:
-                        self._set_credential_based_on_type(service_name, key_val[0].lower(), key_val[1].lower())
+                        self._set_credential_based_on_type(service_name, key_val[0].lower(), key_val[1])
 
 
     def _set_credential_based_on_type(self, service_name, key, value):
