@@ -15,4 +15,7 @@
 # limitations under the License.
 
 from .recognize_abstract_callback import RecognizeCallback
-from .speech_to_text_websocket_listener import RecognizeListener
+from .recognize_listener import RecognizeListener
+from .audio_source import AudioSource
+from .synthesize_callback import SynthesizeCallback
+from .synthesize_listener import SynthesizeListener
